#!/usr/bin/python
#
# Copyright 2018-2022 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 1.19.0
    Contact: contact@polyaxon.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from polyaxon_sdk.configuration import Configuration


class V1SectionSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'is_minimized': 'bool',
        'columns': 'int',
        'height': 'int',
        'widgets': 'list[object]',
        'page_index': 'int',
        'page_size': 'int'
    }

    attribute_map = {
        'name': 'name',
        'is_minimized': 'is_minimized',
        'columns': 'columns',
        'height': 'height',
        'widgets': 'widgets',
        'page_index': 'pageIndex',
        'page_size': 'pageSize'
    }

    def __init__(self, name=None, is_minimized=None, columns=None, height=None, widgets=None, page_index=None, page_size=None, local_vars_configuration=None):  # noqa: E501
        """V1SectionSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._is_minimized = None
        self._columns = None
        self._height = None
        self._widgets = None
        self._page_index = None
        self._page_size = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if is_minimized is not None:
            self.is_minimized = is_minimized
        if columns is not None:
            self.columns = columns
        if height is not None:
            self.height = height
        if widgets is not None:
            self.widgets = widgets
        if page_index is not None:
            self.page_index = page_index
        if page_size is not None:
            self.page_size = page_size

    @property
    def name(self):
        """Gets the name of this V1SectionSpec.  # noqa: E501


        :return: The name of this V1SectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1SectionSpec.


        :param name: The name of this V1SectionSpec.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def is_minimized(self):
        """Gets the is_minimized of this V1SectionSpec.  # noqa: E501


        :return: The is_minimized of this V1SectionSpec.  # noqa: E501
        :rtype: bool
        """
        return self._is_minimized

    @is_minimized.setter
    def is_minimized(self, is_minimized):
        """Sets the is_minimized of this V1SectionSpec.


        :param is_minimized: The is_minimized of this V1SectionSpec.  # noqa: E501
        :type is_minimized: bool
        """

        self._is_minimized = is_minimized

    @property
    def columns(self):
        """Gets the columns of this V1SectionSpec.  # noqa: E501


        :return: The columns of this V1SectionSpec.  # noqa: E501
        :rtype: int
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this V1SectionSpec.


        :param columns: The columns of this V1SectionSpec.  # noqa: E501
        :type columns: int
        """

        self._columns = columns

    @property
    def height(self):
        """Gets the height of this V1SectionSpec.  # noqa: E501


        :return: The height of this V1SectionSpec.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this V1SectionSpec.


        :param height: The height of this V1SectionSpec.  # noqa: E501
        :type height: int
        """

        self._height = height

    @property
    def widgets(self):
        """Gets the widgets of this V1SectionSpec.  # noqa: E501


        :return: The widgets of this V1SectionSpec.  # noqa: E501
        :rtype: list[object]
        """
        return self._widgets

    @widgets.setter
    def widgets(self, widgets):
        """Sets the widgets of this V1SectionSpec.


        :param widgets: The widgets of this V1SectionSpec.  # noqa: E501
        :type widgets: list[object]
        """

        self._widgets = widgets

    @property
    def page_index(self):
        """Gets the page_index of this V1SectionSpec.  # noqa: E501


        :return: The page_index of this V1SectionSpec.  # noqa: E501
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """Sets the page_index of this V1SectionSpec.


        :param page_index: The page_index of this V1SectionSpec.  # noqa: E501
        :type page_index: int
        """

        self._page_index = page_index

    @property
    def page_size(self):
        """Gets the page_size of this V1SectionSpec.  # noqa: E501


        :return: The page_size of this V1SectionSpec.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this V1SectionSpec.


        :param page_size: The page_size of this V1SectionSpec.  # noqa: E501
        :type page_size: int
        """

        self._page_size = page_size

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1SectionSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1SectionSpec):
            return True

        return self.to_dict() != other.to_dict()



#!/usr/bin/python
#
# Copyright 2018-2022 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 1.19.0
    Contact: contact@polyaxon.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from polyaxon_sdk.configuration import Configuration


class V1StageCondition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'V1Stages',
        'status': 'str',
        'reason': 'str',
        'message': 'str',
        'last_update_time': 'datetime',
        'last_transition_time': 'datetime'
    }

    attribute_map = {
        'type': 'type',
        'status': 'status',
        'reason': 'reason',
        'message': 'message',
        'last_update_time': 'last_update_time',
        'last_transition_time': 'last_transition_time'
    }

    def __init__(self, type=None, status=None, reason=None, message=None, last_update_time=None, last_transition_time=None, local_vars_configuration=None):  # noqa: E501
        """V1StageCondition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._status = None
        self._reason = None
        self._message = None
        self._last_update_time = None
        self._last_transition_time = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if status is not None:
            self.status = status
        if reason is not None:
            self.reason = reason
        if message is not None:
            self.message = message
        if last_update_time is not None:
            self.last_update_time = last_update_time
        if last_transition_time is not None:
            self.last_transition_time = last_transition_time

    @property
    def type(self):
        """Gets the type of this V1StageCondition.  # noqa: E501


        :return: The type of this V1StageCondition.  # noqa: E501
        :rtype: V1Stages
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this V1StageCondition.


        :param type: The type of this V1StageCondition.  # noqa: E501
        :type type: V1Stages
        """

        self._type = type

    @property
    def status(self):
        """Gets the status of this V1StageCondition.  # noqa: E501


        :return: The status of this V1StageCondition.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this V1StageCondition.


        :param status: The status of this V1StageCondition.  # noqa: E501
        :type status: str
        """

        self._status = status

    @property
    def reason(self):
        """Gets the reason of this V1StageCondition.  # noqa: E501


        :return: The reason of this V1StageCondition.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this V1StageCondition.


        :param reason: The reason of this V1StageCondition.  # noqa: E501
        :type reason: str
        """

        self._reason = reason

    @property
    def message(self):
        """Gets the message of this V1StageCondition.  # noqa: E501


        :return: The message of this V1StageCondition.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this V1StageCondition.


        :param message: The message of this V1StageCondition.  # noqa: E501
        :type message: str
        """

        self._message = message

    @property
    def last_update_time(self):
        """Gets the last_update_time of this V1StageCondition.  # noqa: E501


        :return: The last_update_time of this V1StageCondition.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):
        """Sets the last_update_time of this V1StageCondition.


        :param last_update_time: The last_update_time of this V1StageCondition.  # noqa: E501
        :type last_update_time: datetime
        """

        self._last_update_time = last_update_time

    @property
    def last_transition_time(self):
        """Gets the last_transition_time of this V1StageCondition.  # noqa: E501


        :return: The last_transition_time of this V1StageCondition.  # noqa: E501
        :rtype: datetime
        """
        return self._last_transition_time

    @last_transition_time.setter
    def last_transition_time(self, last_transition_time):
        """Sets the last_transition_time of this V1StageCondition.


        :param last_transition_time: The last_transition_time of this V1StageCondition.  # noqa: E501
        :type last_transition_time: datetime
        """

        self._last_transition_time = last_transition_time

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1StageCondition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1StageCondition):
            return True

        return self.to_dict() != other.to_dict()



#!/usr/bin/python
#
# Copyright 2018-2022 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 1.19.0
    Contact: contact@polyaxon.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from polyaxon_sdk.configuration import Configuration


class V1Component(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'version': 'float',
        'kind': 'str',
        'name': 'str',
        'description': 'str',
        'tags': 'list[str]',
        'presets': 'list[str]',
        'queue': 'str',
        'cache': 'V1Cache',
        'termination': 'V1Termination',
        'plugins': 'V1Plugins',
        'hooks': 'list[V1Hook]',
        'inputs': 'list[V1IO]',
        'outputs': 'list[V1IO]',
        'build': 'V1Build',
        'run': 'object',
        'template': 'V1Template',
        'is_approved': 'bool',
        'cost': 'float'
    }

    attribute_map = {
        'version': 'version',
        'kind': 'kind',
        'name': 'name',
        'description': 'description',
        'tags': 'tags',
        'presets': 'presets',
        'queue': 'queue',
        'cache': 'cache',
        'termination': 'termination',
        'plugins': 'plugins',
        'hooks': 'hooks',
        'inputs': 'inputs',
        'outputs': 'outputs',
        'build': 'build',
        'run': 'run',
        'template': 'template',
        'is_approved': 'isApproved',
        'cost': 'cost'
    }

    def __init__(self, version=None, kind=None, name=None, description=None, tags=None, presets=None, queue=None, cache=None, termination=None, plugins=None, hooks=None, inputs=None, outputs=None, build=None, run=None, template=None, is_approved=None, cost=None, local_vars_configuration=None):  # noqa: E501
        """V1Component - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._version = None
        self._kind = None
        self._name = None
        self._description = None
        self._tags = None
        self._presets = None
        self._queue = None
        self._cache = None
        self._termination = None
        self._plugins = None
        self._hooks = None
        self._inputs = None
        self._outputs = None
        self._build = None
        self._run = None
        self._template = None
        self._is_approved = None
        self._cost = None
        self.discriminator = None

        if version is not None:
            self.version = version
        if kind is not None:
            self.kind = kind
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if tags is not None:
            self.tags = tags
        if presets is not None:
            self.presets = presets
        if queue is not None:
            self.queue = queue
        if cache is not None:
            self.cache = cache
        if termination is not None:
            self.termination = termination
        if plugins is not None:
            self.plugins = plugins
        if hooks is not None:
            self.hooks = hooks
        if inputs is not None:
            self.inputs = inputs
        if outputs is not None:
            self.outputs = outputs
        if build is not None:
            self.build = build
        if run is not None:
            self.run = run
        if template is not None:
            self.template = template
        if is_approved is not None:
            self.is_approved = is_approved
        if cost is not None:
            self.cost = cost

    @property
    def version(self):
        """Gets the version of this V1Component.  # noqa: E501


        :return: The version of this V1Component.  # noqa: E501
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this V1Component.


        :param version: The version of this V1Component.  # noqa: E501
        :type version: float
        """

        self._version = version

    @property
    def kind(self):
        """Gets the kind of this V1Component.  # noqa: E501


        :return: The kind of this V1Component.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this V1Component.


        :param kind: The kind of this V1Component.  # noqa: E501
        :type kind: str
        """

        self._kind = kind

    @property
    def name(self):
        """Gets the name of this V1Component.  # noqa: E501


        :return: The name of this V1Component.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1Component.


        :param name: The name of this V1Component.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this V1Component.  # noqa: E501


        :return: The description of this V1Component.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1Component.


        :param description: The description of this V1Component.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def tags(self):
        """Gets the tags of this V1Component.  # noqa: E501


        :return: The tags of this V1Component.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this V1Component.


        :param tags: The tags of this V1Component.  # noqa: E501
        :type tags: list[str]
        """

        self._tags = tags

    @property
    def presets(self):
        """Gets the presets of this V1Component.  # noqa: E501


        :return: The presets of this V1Component.  # noqa: E501
        :rtype: list[str]
        """
        return self._presets

    @presets.setter
    def presets(self, presets):
        """Sets the presets of this V1Component.


        :param presets: The presets of this V1Component.  # noqa: E501
        :type presets: list[str]
        """

        self._presets = presets

    @property
    def queue(self):
        """Gets the queue of this V1Component.  # noqa: E501


        :return: The queue of this V1Component.  # noqa: E501
        :rtype: str
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """Sets the queue of this V1Component.


        :param queue: The queue of this V1Component.  # noqa: E501
        :type queue: str
        """

        self._queue = queue

    @property
    def cache(self):
        """Gets the cache of this V1Component.  # noqa: E501


        :return: The cache of this V1Component.  # noqa: E501
        :rtype: V1Cache
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this V1Component.


        :param cache: The cache of this V1Component.  # noqa: E501
        :type cache: V1Cache
        """

        self._cache = cache

    @property
    def termination(self):
        """Gets the termination of this V1Component.  # noqa: E501


        :return: The termination of this V1Component.  # noqa: E501
        :rtype: V1Termination
        """
        return self._termination

    @termination.setter
    def termination(self, termination):
        """Sets the termination of this V1Component.


        :param termination: The termination of this V1Component.  # noqa: E501
        :type termination: V1Termination
        """

        self._termination = termination

    @property
    def plugins(self):
        """Gets the plugins of this V1Component.  # noqa: E501


        :return: The plugins of this V1Component.  # noqa: E501
        :rtype: V1Plugins
        """
        return self._plugins

    @plugins.setter
    def plugins(self, plugins):
        """Sets the plugins of this V1Component.


        :param plugins: The plugins of this V1Component.  # noqa: E501
        :type plugins: V1Plugins
        """

        self._plugins = plugins

    @property
    def hooks(self):
        """Gets the hooks of this V1Component.  # noqa: E501


        :return: The hooks of this V1Component.  # noqa: E501
        :rtype: list[V1Hook]
        """
        return self._hooks

    @hooks.setter
    def hooks(self, hooks):
        """Sets the hooks of this V1Component.


        :param hooks: The hooks of this V1Component.  # noqa: E501
        :type hooks: list[V1Hook]
        """

        self._hooks = hooks

    @property
    def inputs(self):
        """Gets the inputs of this V1Component.  # noqa: E501


        :return: The inputs of this V1Component.  # noqa: E501
        :rtype: list[V1IO]
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """Sets the inputs of this V1Component.


        :param inputs: The inputs of this V1Component.  # noqa: E501
        :type inputs: list[V1IO]
        """

        self._inputs = inputs

    @property
    def outputs(self):
        """Gets the outputs of this V1Component.  # noqa: E501


        :return: The outputs of this V1Component.  # noqa: E501
        :rtype: list[V1IO]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this V1Component.


        :param outputs: The outputs of this V1Component.  # noqa: E501
        :type outputs: list[V1IO]
        """

        self._outputs = outputs

    @property
    def build(self):
        """Gets the build of this V1Component.  # noqa: E501


        :return: The build of this V1Component.  # noqa: E501
        :rtype: V1Build
        """
        return self._build

    @build.setter
    def build(self, build):
        """Sets the build of this V1Component.


        :param build: The build of this V1Component.  # noqa: E501
        :type build: V1Build
        """

        self._build = build

    @property
    def run(self):
        """Gets the run of this V1Component.  # noqa: E501


        :return: The run of this V1Component.  # noqa: E501
        :rtype: object
        """
        return self._run

    @run.setter
    def run(self, run):
        """Sets the run of this V1Component.


        :param run: The run of this V1Component.  # noqa: E501
        :type run: object
        """

        self._run = run

    @property
    def template(self):
        """Gets the template of this V1Component.  # noqa: E501


        :return: The template of this V1Component.  # noqa: E501
        :rtype: V1Template
        """
        return self._template

    @template.setter
    def template(self, template):
        """Sets the template of this V1Component.


        :param template: The template of this V1Component.  # noqa: E501
        :type template: V1Template
        """

        self._template = template

    @property
    def is_approved(self):
        """Gets the is_approved of this V1Component.  # noqa: E501


        :return: The is_approved of this V1Component.  # noqa: E501
        :rtype: bool
        """
        return self._is_approved

    @is_approved.setter
    def is_approved(self, is_approved):
        """Sets the is_approved of this V1Component.


        :param is_approved: The is_approved of this V1Component.  # noqa: E501
        :type is_approved: bool
        """

        self._is_approved = is_approved

    @property
    def cost(self):
        """Gets the cost of this V1Component.  # noqa: E501


        :return: The cost of this V1Component.  # noqa: E501
        :rtype: float
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """Sets the cost of this V1Component.


        :param cost: The cost of this V1Component.  # noqa: E501
        :type cost: float
        """

        self._cost = cost

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Component):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1Component):
            return True

        return self.to_dict() != other.to_dict()
